@@ -273,11 +273,11 @@ def get_lane_impacts(lane_impacts, direction):
             return get_lanes_list(impact['laneClosures'], impact['laneCount'], impact['closedLaneTypes'])
 
 
-def any_lanes_closed(lanes):
+def all_lanes_open(lanes):
     for i in lanes:
         if i['status'] != 'open':
-            return True
-    return False
+            return False
+    return True
 
 
 def create_rtdh_standard_msg(pd):
@@ -309,7 +309,8 @@ def create_rtdh_standard_msg(pd):
         restrictions.append({'type': 'permitted-oversize-loads-prohibited'})
 
     lane_impacts = get_lane_impacts(pd.get("properties/laneImpacts"), pd.get("properties/direction"))
-    if not any_lanes_closed(lane_impacts):
+    # if direction != recorded_direction and all_lanes_open(lane_impacts):
+    if direction != recorded_direction or not all_lanes_open(lane_impacts):
         return {}
 
 
