@@ -7,7 +7,7 @@ import uuid
 
 from wzdx.sample_files.validation_schema import wzdx_v40_feed, road_restriction_v40_feed
 
-from wzdx.tools import date_tools, polygon_tools, wzdx_translator
+from wzdx.tools import date_tools, wzdx_translator
 
 PROGRAM_NAME = 'PlannedEventsTranslator'
 PROGRAM_VERSION = '1.0'
@@ -21,7 +21,6 @@ def main():
 
     planned_events_obj = json.loads(open(input_file, 'r').read())
     wzdx = wzdx_creator(planned_events_obj)
-    print(wzdx['road_event_feed_info'])
     try:
         event_type = wzdx['features'][0]['properties']['core_details']['event_type']
     except:
